# Copyright 2023 Luminary Cloud, Inc. All Rights Reserved.
import dbm
import logging
import os
from typing import Optional

from .config import LC_CREDENTIALS_DIR

logger = logging.getLogger(__name__)


class CredentialsStore:
    """
    Wrapper for dbm.

    If LC_CREDENTIALS_DIR is None, it does nothing.
    https://docs.python.org/3/library/dbm.html
    """

    def __init__(self, dbname: str):
        self._path = None
        if LC_CREDENTIALS_DIR is not None:
            os.makedirs(LC_CREDENTIALS_DIR, exist_ok=True)
            self._path = os.path.join(LC_CREDENTIALS_DIR, dbname)

    def save(self, key: str, val: Optional[str]) -> None:
        if self._path is not None:
            logger.info(f"Writing value with key '{key}' to {self._path}.")
            with dbm.open(self._path, "c") as store:
                if val is None:
                    del store[key]
                else:
                    store[key] = val

    def recall(self, key: str) -> Optional[str]:
        if self._path is not None:
            logger.info(f"Attempting to read value with key '{key}' from {self._path}.")
            with dbm.open(self._path, "c") as store:
                if key in store:
                    return store[key].decode()
            logger.info(f"Key not found: {key}.")
        return None
